#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#

import datetime


def isSchaltjahrJJ(jj):
    if (jj % 400) == 0:
        return True
    elif (jj % 100) == 0:
        return False
    elif (jj % 4) == 0:
        return True
    return False


def isSchaltjahr(d):
    jj = d.year
    return isSchaltjahr(jj)


# Datum des Ostersonntags geändert 10.05.2018
# https://bauforum.wirklichewelt.de/index.php?id=8525
def ostersonntag(jahr):
    A = jahr % 19
    K = jahr // 100
    M = 15 + (3 * K + 3) // 4 - (8 * K + 13) // 25
    D = (19 * A + M) % 30
    S = 2 - (3 * K + 3) // 4
    R = D // 29 + (D // 28 - D // 29) * (A // 11)
    OG = 21 + D + R
    SZ = 7 - (jahr + jahr // 4 + S) % 7
    OE = 7 - (OG - SZ) % 7
    OS = (OG + OE)
    if OS > 31:
        return (jahr, 4, OS - 31)
    else:
        return (jahr, 3, OS)


# Tagesnummer des Datums
def tagesnummer(jj, mm, tt):
    tn = 0
    if mm > 1:
        tn = tn + 31
    if mm > 2:
        tn = tn + 28
    if mm > 3:
        tn = tn + 31
    if mm > 4:
        tn = tn + 30
    if mm > 5:
        tn = tn + 31
    if mm > 6:
        tn = tn + 30
    if mm > 7:
        tn = tn + 31
    if mm > 8:
        tn = tn + 31
    if mm > 9:
        tn = tn + 30
    if mm > 10:
        tn = tn + 31
    if mm > 11:
        tn = tn + 30
    tn = tn + tt
    if isSchaltjahrJJ(jj) and (mm > 2):
        tn = tn + 1
    return tn


# Tagesnummer des Ostersonntags
def ostersonntag_tn(jahr):
    jj, mm, tt = ostersonntag(jahr)
    tn = tagesnummer(jj, mm, tt)
    return (tn)


cSN = 'SN'
cBY = 'BY'
cSH = 'SH'
cBE = 'BE'
cMV = 'MV'
cBB = 'BB'
cST = 'ST'
cTH = 'TH'
cHH = 'HH'
cHB = 'HB'
cNW = 'NW'
cHS = 'HS'
cBW = 'BW'
cRP = 'RP'
cSL = 'SL'


def sFeiertag(d, aBundesland):
    jj = d.year
    mm = d.month
    tt = d.day
    os = ostersonntag_tn(jj)
    tn = tagesnummer(jj, mm, tt)
    s = ""
    if tn == os:
        s = "Ostersonntag"
    elif tn == os + 1:
        s = "Ostermontag"
    elif tn == os - 2:
        s = "Karfreitag"
    elif tn == os + 39:
        s = 'Himmelfahrt'
    elif tn == os + 49:
        s = "Pfingstsonntag";
    elif tn == os + 50:
        s = "Pfingstmontag"
    elif (tn == os + 60) and (aBundesland in [cBW, cBY, cHS, cNW, cRP, cSL]):
        s = "Fronleichnam"
    elif (mm == 0o1) and (tt == 0o1):
        s = "Neujahr"
    elif (mm == 0o5) and (tt == 0o1):
        s = "Maifeiertag"
    elif (mm == 10) and (tt == 0o3):
        s = "Tag der Einheit"
    elif (mm == 12) and (tt == 25):
        s = "Weihnachten"
    elif (mm == 12) and (tt == 26):
        s = "Weihnachten"
    elif (mm == 0o1) and (tt == 0o6) and (aBundesland in [cBW, cBY, cST]):
        s = "Heilige Drei Könige"
    elif (mm == 8) and (tt == 15) and (aBundesland in [cBY, cSL]):
        s = "Mariä Aufnahme"
    elif (mm == 10) and (tt == 31) and (aBundesland in [cBB, cMV, cSN, cST, cTH]):
        s = "Reformationstag"
    elif (mm == 11) and (tt == 0o1) and (aBundesland in [cBW, cBY, cNW, cRP, cSL]):
        s = "Allerheiligen"
    elif (mm==11) and (aBundesland in [cSN]):
        #Wikipedia.de   Im 20. Jahrhundert wurde der Buß und Bettag meist
        #am Mittwoch vor dem Ewigkeitssonntag
        #(der letzte Sonntag des Kirchenjahres) begangen,
        #also am Mittwoch vor dem 23. November bzw. 11 Tage vor dem ersten Adventssonntag.
        #Die Termine des Buß- und Bettages bis 2010 sind:
        #16.11.2005, 22.11.2006, 21.11.2007, 19.11.2008, 18.11.2009 und 17.11.2010.
        dx = datetime.date(jj,mm,23-1)
        #den Mittwoch vor dem 23.11. suchen
        while dx.weekday()!=2:
            dx = dx + datetime.timedelta(days=-1)
        if (tt == dx.day):
            s = u"Buß-und Bettag"
    return (s)


def alleFeiertage(jj, aBundesland):
    # print(ostersonntag(jj))
    d = datetime.date(jj, 0o1, 0o1)
    difference1 = datetime.timedelta(days=1)
    for i in range(365):
        s = sFeiertag(d, aBundesland)
        if s != "":
            print(d, s)
        d = d + difference1


def alleJahre():
    s = ''
    for i in range(50):
        s = '%s[%s]\n' % (s, str(i + 1958))
    return s


def main():
    alleFeiertage(2019, 'SN')
    return 0


if __name__ == '__main__':
    main()
