#! /usr/bin/python3
# -*- coding: utf-8 -*-

from bottle import route, get, post, template, static_file, request
import os
import datetime
import time
import wnfwecker_const as C
import wnfwecker_tools as T
import wnfwecker_weckzeit as W
import wnfwecker_moc as M
import wnfwecker_ini
import wnfwecker_update

www = os.path.join(os.path.dirname(__file__), 'www')
ini = wnfwecker_ini.iniObject()


def keinZugriff(daten):
    s = ('Kein Zugriff %s (Serverzeit %s)' % (C.PROGBUILD, (time.strftime("%d.%m.%Y %H:%M:%S"))))
    return template('<b>Hello {{name}}!</b><hr>{{meldung}}', name=daten, meldung=s)


def statusZeilen():
    aStatus = (('Version', C.PROGBUILD),
               ('Proxy-Hostname', T.getHostname()),
               ('Default GatewayX', T.getDefaultGateWay()),
               ('Inidatei', ini.IniDateiname),
               ('Logfile', T.logHandler.baseFilename),
               ('Soundcheck mit', M.cFanfareOgg),
               ('zuletzt aktualisiert', '%s (Serverzeit)' % (str(datetime.datetime.today()))),
               ('nächste Weckzeit', W.getNextWeckzeit(datetime.datetime.today(), T.logFile)),
               ('Songtitel', M.getTitel())
               )
    return aStatus


def iniWeckzeit(aKey):
    return (aKey, ini.weckZeit(aKey))


def iniWeckzeiten():
    ini.refreshWennNoetig(T.logFile)
    aStatus = (iniWeckzeit('Montag'),
               iniWeckzeit('Dienstag'),
               iniWeckzeit('Mittwoch'),
               iniWeckzeit('Donnerstag'),
               iniWeckzeit('Freitag'),
               iniWeckzeit('Samstag'),
               iniWeckzeit('Sonntag')
               )
    return aStatus


def weckerstatus():
    aCaption = C.PROGNAME
    output = template('www_status',
                      title=aCaption,
                      WeckerStatus=statusZeilen(),
                      Weckzeiten=iniWeckzeiten()
                      )
    return output


def weckerOffline(aKommando,aErgebnis):
    aCaption = C.PROGNAME
    output = template('www_offline',
                      title=aCaption,
                      kommando=aKommando,
                      ergebnis=aErgebnis
                      )
    return output


@get("/css/<filepath:re:.*\.css>")
def css(filepath):
    return static_file(filepath, root=os.path.join(www, "css"))


@get("/img/<filepath:re:.*\.(jpg|png|gif|ico|svg)>")
def img(filepath):
    return static_file(filepath, root=os.path.join(www, "img"))


@get("/js/<filepath:re:.*\.js>")
def js(filepath):
    return static_file(filepath, root=os.path.join(www, "js"))


@get("/<filepath:re:.*\.html>")
def html(filepath):
    return static_file(filepath, root=www)


@get("/<filepath:re:.*\.json>")
def json(filepath):
    return static_file(filepath, root=www)


@get("/daten/<filepath:re:.*\.csv>")
def csv(filepath):
    return static_file(filepath, root=os.path.join(www, "daten"))


@route('/')
def index():
    return weckerstatus()


@post("/soundcheck")
def soundcheck():
    M.fanfare()
    return weckerstatus()


@post("/startseite")
def startseite():
    M.fanfare()
    return weckerstatus()


def offline(aKommando):
    M.fanfare()
    if (T.rebootErlaubt()):
        s = 'Kommando Wird ausgeführt'
        r = T.kommando(aKommando)
    else:
        s = 'Kommando nicht erlaubt'
        r = ''
    s = '%s: %s' % (s, aKommando)
    T._info(s)
    return weckerOffline(s,r)


@post("/shutdown")
def shutdown():
    return offline('sudo poweroff')


@post("/reboot")
def reboot():
    return offline('sudo reboot')

@post("/update")
def update():
    M.fanfare()
    wnfwecker_update.downloadUpdate()
    return weckerstatus()


@post("/speichern")
def speichern():
    werktags = request.forms.get('werktags')
    samstags = request.forms.get('samstags')
    sonntags = request.forms.get('sonntags')
    volume = request.forms.get('volume')
    T._info('%s %s %s %s' % (werktags, samstags, sonntags, volume))
    ini.schreibeWeckzeit(werktags,samstags)
    M.playIsOk()
    return weckerstatus()


def startBottle():
    from bottle import run, debug
    debug(True)
    aPortClient = T.iniGetBottlePort()
    T._info('wnfwecker_http lauscht am Port %s.' % (aPortClient))
    run(host='0.0.0.0', port=aPortClient)


def main():
    # os.chdir(os.path.dirname(__file__))
    T._info('wnfwecker_http für %s.%s gestartet.' % (C.PROGNAME, C.PROGBUILD))
    startBottle()


if __name__ == '__main__':
    main()
