#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#

# Literatur
# MOC - music on console
# http://moc.daper.net 

import os
import sys
import time
import datetime
import configparser
import wnfwecker_tools as T

        
cSection_WZ = "Weckzeiten"
cSection_Radiosender = "Radiosender"
cSection_MusikDir = "MusikDir"
cSection_Volume = "Volume"
cSection_Status = "Status"
cSection_Urlaub = "Urlaub"

class iniObject(object):
    def __init__(self):
        self.IniDateiname = ''
        if len(sys.argv) > 1:
            self.IniDateiname = sys.argv[1]
        if not T.wnfFileExists(self.IniDateiname):
            self.IniDateiname = os.environ["HOME"]
            self.IniDateiname = "%s/.config/wlsoft/wnfwecker.ini" % (self.IniDateiname)
        if not T.wnfFileExists(self.IniDateiname):
            self.IniDateiname = "./wnfwecker.ini"
        self.IniTimestamp = 0
        self.ini=configparser.ConfigParser()
        if T.wnfFileExists(self.IniDateiname):
            self.ini.read(self.IniDateiname)
            self.IniTimestamp = os.stat(self.IniDateiname).st_mtime
            # print self.IniTimestamp
        print(self.IniDateiname)
        
    def leseStrDefault(self,aSection,aName,aDefault):
        """" Lesen der Variablen aus der Ini-Datei """
        try:
            s = self.ini.get(aSection, aName)
        except configparser.NoSectionError:
            s = aDefault
        except configparser.NoOptionError:
            s = aDefault
        #print "Ini gelesen %s %s %s " % (aSection,aName,s)
        return s
        
    def leseIntDefault(self,aSection,aName,aDefault):
        s = self.leseStrDefault(aSection,aName,'')
        if (s==''):
            return aDefault
        else:
            return T.strToIntDef(s,aDefault)
        
    def leseStr(self,aSection,aName):
        """" Lesen der Variablen aus der Ini-Datei """
        return self.leseStrDefault(ini,aSection,aName,'')

    def schreibeStr(self,aSection,aName,aWert):
        self.ini.set(aSection,aName,aWert)

    def schreibeWeckzeit(self,aWerktags,aSamstag):
        self.schreibeStr(cSection_WZ,'Montag',aWerktags)
        self.schreibeStr(cSection_WZ,'Dienstag',aWerktags)
        self.schreibeStr(cSection_WZ,'Mittwoch',aWerktags)
        self.schreibeStr(cSection_WZ,'Donnerstag',aWerktags)
        self.schreibeStr(cSection_WZ,'Freitag',aWerktags)
        self.schreibeStr(cSection_WZ,'Samstag',aSamstag)
        self.speichern()

    def speichern(self):
        print(type(self.ini))
        print(self.IniDateiname)
        with open(self.IniDateiname, 'w') as configfile:
            self.ini.write(configfile)
        #self.ini.write(self.IniDateiname)

    def bundesland(self):
        return self.leseStrDefault(cSection_Status,'Bundesland',"SN")    
    
    def weckZeit(self,aWochentag):
        return self.leseStrDefault(cSection_WZ,aWochentag,"05:20")    
                
    def weckDauerInMinuten(self):
        return self.leseIntDefault(cSection_WZ,"Weckdauer",30)
                 

    def radioSender_1(self):
        return self.leseStrDefault(cSection_Radiosender,"1","http://www.wdr.de/wdrlive/media/einslive.m3u")    

    def musikDir_1(self):
        aDefault = "%s/Musik/" % (os.environ["HOME"])
        return self.leseStrDefault(cSection_MusikDir,"1",aDefault)    


    def volumeControl(self):
        return self.leseStrDefault(cSection_Volume,"amixer_sset","PCM") 

    def volumeStep(self):
        return self.leseStrDefault(cSection_Volume,"Step","2") 

    def volumeMaxProzent(self):
        return self.leseStrDefault(cSection_Volume,"MaxProzent","70") 
        
    def isEingeschaltet(self):    
        wert = self.leseStrDefault(cSection_Status,"Eingeschaltet","True")
        cJaWerte = ['Ja', 'True', 'J', 'Yes', 'Y']
        if any(wert in s for s in cJaWerte):
            return True
        else:
            return False

    def isOnline(self):    
        wert = self.leseStrDefault(cSection_Status,"Online","True")
        cJaWerte = ['Ja', 'True', 'J', 'Yes', 'Y']
        if any(wert in s for s in cJaWerte):
            return True
        else:
            return False

    def dateBetween(self,datum,datumvonbis):
        if (len(datumvonbis)!=21):
            return False
        #datum im Format tt.mm.jjjj
        #datumvonbis im Format tt.mm.jjjj-tt.mm.jjjj
        datumvon = datumvonbis.split('-',1)[0]
        datumbis = datumvonbis.split('-',1)[1]
        #print datumvonbis,datumvon
        dt = datetime.date(*time.strptime(datum, "%d.%m.%Y")[0:3])
        von = datetime.date(*time.strptime(datumvon, "%d.%m.%Y")[0:3])
        bis = datetime.date(*time.strptime(datumbis, "%d.%m.%Y")[0:3])
        #print von,dt,bis
        return von<=dt<=bis


    def isUrlaub(self,dt):
        try:
            urlaub_items = self.ini.items(cSection_Urlaub)
            #print urlaub_items
            for key, datum in urlaub_items:        
                #print dt,key,datum
                if (dt==datum):
                    return True
                elif self.dateBetween(dt,datum):
                    return True
            return False
        except configparser.NoSectionError:
            return False
        except configparser.NoOptionError:
            return False
        
    def refreshWennNoetig(self,logFile):
        aTimestamp = os.stat(self.IniDateiname).st_mtime
        if (self.IniTimestamp<aTimestamp):
            self.ini.read(self.IniDateiname)
            self.IniTimestamp = os.stat(self.IniDateiname).st_mtime
            s='%s neu gelesen %s ' % (self.IniDateiname,self.IniTimestamp)
            print(s)
            if (logFile):
                logFile.debug(s)
            return True
        else:
            return False


def main():
    aIni=iniObject()
    aIni.refreshWennNoetig(None)
    print(aIni.weckDauerInMinuten())
    print(aIni.isEingeschaltet())
    print(aIni.isUrlaub('15.05.2015'))
    print(aIni.isUrlaub('19.05.2015'))
    return 0

if __name__ == '__main__':
    main()
        
