#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#

from PyQt4 import QtGui, QtCore
import time
import datetime
import sys
import wnfwecker_moc as R
import wnfwecker_weckzeit as W
import logging
from logging.handlers import RotatingFileHandler

logFormatter = logging.Formatter('%(asctime)s %(levelname)s) %(message)s')
logFileName = 'wnfwecker.log'

logHandler = RotatingFileHandler(logFileName, mode='a', maxBytes=5 * 1024 * 1024,
                                 backupCount=2, encoding=None, delay=0)
logHandler.setFormatter(logFormatter)
logHandler.setLevel(logging.INFO)

logFile = logging.getLogger('root')
logFile.setLevel(logging.INFO)
logFile.addHandler(logHandler)


class Window(QtGui.QWidget):
    def __init__(self):
        QtGui.QWidget.__init__(self)
        self.setWindowTitle(self.tr('wnfWecker 0.3'))
        
        self.fFullScreen = False
        self.fRadioEin = False
        self.fWeckerEin = False
        self.fMusikEin = False
        self.fmitSekundenAnzeige = True
        
        self.fMocOK = R.initPlay(logFile)
        
        layout = QtGui.QGridLayout(self)
        
        palette = QtGui.QPalette()
        palette.setColor(QtGui.QPalette.Foreground,QtCore.Qt.green)
        palette.setColor(QtGui.QPalette.Background,QtCore.Qt.black)

        self.setPalette(palette)
        
        self.btnWeckzeiten = self.initButton("Weckzeiten",0,layout,self.onWeckzeitenClicked)
        self.btnFullScreen = self.initButton("Vollbild",1,layout,self.onFullSreenClicked)
        self.btnRadio = self.initButton("Radio",2,layout,self.onRadioClicked)
        self.btnClose = self.initButton("Beenden",3,layout,self.onCloseClicked)
        
        
        self.labelUhr = QtGui.QLabel('07:00')
        #self.labelUhr.setFixedWidth(460)
        self.labelUhr.setAlignment(QtCore.Qt.AlignCenter | QtCore.Qt.AlignVCenter)
        self.labelUhr.setPalette(palette)
        font = QtGui.QFont()
        font.setBold(True)
        font.setPointSize(140)
        self.labelUhr.setFont(font)
        #self.labelUhr.setFrameStyle(QtGui.QFrame.Panel)
        #Die Uhrzeit belegt eine Zeile und 3 Spalten
        layout.addWidget(self.labelUhr, 0, 1, 1, 2)

        self.labelFeme = QtGui.QLabel('')
        self.labelFeme.setAlignment(QtCore.Qt.AlignCenter | QtCore.Qt.AlignVCenter)
        self.labelFeme.setFixedHeight(30)
        self.labelFeme.setFixedWidth(800)
        self.labelFeme.setPalette(palette)
        font = QtGui.QFont()
        font.setBold(True)
        font.setPointSize(20)
        self.labelFeme.setFont(font)
        #self.labelFeme.setFrameStyle(QtGui.QFrame.Panel)
        #Feme belegt eine Zeile und 4 Spalten
        layout.addWidget(self.labelFeme, 2, 0, 1, 4)

        self.sliderVolume = QtGui.QSlider(self)
        self.sliderVolume.setOrientation(QtCore.Qt.Horizontal)
        self.sliderVolume.setFixedHeight(60)
        #Slider belegt eine Zeile und 4 Spalten
        layout.addWidget(self.sliderVolume, 3, 0, 1, 4)

        self.sliderVolume.valueChanged.connect(self.onVolumeChanged)
        self.sliderVolume.setValue(R.getVolumeMaxProzent(logFile))

        #self.sliderRechts = QtGui.QDial(self)
        #self.sliderRechts.setNotchesVisible(True)
        #Slider belegt eine Zeile und 1 Spalte
        #layout.addWidget(self.sliderRechts, 0, 3, 1, 1)

        
        #self.checkUhrzeit()

        # create Worker
        self.anzeigeUhrzeit = UhrzeitThread(self.labelUhr,self.labelFeme)
        self.anzeigeUhrzeit.start()

        
    def initButton(self,aCaption,aBtnNummer,aLayout,aClicked):
        btn = QtGui.QPushButton(aCaption, self)
        btn.setFixedHeight(60)
        btn.setStyleSheet("background-color: darkgray")
        #btn.override_background_color(Gtk.StateFlags.NORMAL, Gdk.RGBA(0.0 , 0.0 , 0.0, 1.0))
        #btn.set_size_request(120, 60)
        btn.clicked.connect(aClicked)
        aLayout.addWidget(btn, 4, aBtnNummer)
        return btn
        
    def onCloseClicked(self):
        if self.fMocOK:
            R.donePlay()
        self.close()
        
    def onFullSreenClicked(self):
        self.fFullScreen = not self.fFullScreen
        if (self.fFullScreen):
            self.showFullScreen()
        else:
            self.showMaximized()

    def onRadioClicked(self):
        if (not self.fMocOK):
            return
        self.fRadioEin = not self.fRadioEin
        self.anzeigeUhrzeit.radioEinAus(self.fRadioEin)

    def onWeckzeitenClicked(self):
        self.fmitSekundenAnzeige = not self.fmitSekundenAnzeige
        self.anzeigeUhrzeit.sekundenEinAus(self.fmitSekundenAnzeige)
        
    def onVolumeChanged(self, value):
        R.volumeProzent(value,logFile)
        self.labelUhr.setText(str(value))

    def feme(self,s):
        self.labelFeme.setText(s)
                                      
class UhrzeitThread(QtCore.QThread):
    def __init__(self,aLabel,aFeme):
        QtCore.QThread.__init__(self)
        self.labelUhr = aLabel
        self.labelFeme = aFeme
        self.exiting = False
        self.fRadioEin = False
        self.fMusikEin = False
        self.fWeckerEin = False
        self.fmitSekundenAnzeige = True

    def run(self):
        if not self.exiting:
            dt = datetime.datetime.today()
            if self.fmitSekundenAnzeige:
                hhmmss = dt.strftime("%H:%M:%S")
            else:
                hhmmss = dt.strftime("%H:%M")
            self.labelUhr.setText(hhmmss)
            #print ("Hello from a QThread!")
            self.checkWeckzeit()
            if (self.fMusikEin):
                self.feme(R.getTitel())
            if self.fmitSekundenAnzeige:
                #print(hhmmss)
                QtCore.QTimer.singleShot(500, self.run)
            else:
                QtCore.QTimer.singleShot(5000, self.run)

    def stop(self):
        self.exiting = True

    def start(self):
        self.exiting = False
        self.run()

    def musikEinAus(self,aEin):
        self.fMusikEin = aEin
        self.feme(str(self.fMusikEin))
        self.run()

    def radioEinAus(self,aEin):
        self.fRadioEin = aEin
        self.feme("Radio %s" % (str(self.fRadioEin)))
        self.run()

    def sekundenEinAus(self,aEin):
        self.fmitSekundenAnzeige = aEin
        self.checkWeckzeit()

    def feme(self,s):
        self.labelFeme.setText(s)

    def checkWeckzeit(self):
        dt = datetime.datetime.today()
        if W.isWeckZeit(dt,logFile):
            self.fWeckerEin = True
        else: 
            self.fWeckerEin = False
            s = W.zeitBisZumAufstehen(dt,logFile)
            self.feme(s)
        self.playMusik()
        
    def playMusik(self):
        if (not self.fMusikEin):
            if (self.fRadioEin or self.fWeckerEin):
                self.fMusikEin = True
                # wenn geweckt wird, dann langsam starten
                R.startPlay(self.fWeckerEin,logFile)
        else:
            if not(self.fRadioEin or self.fWeckerEin):
                self.fMusikEin = False
                R.stopPlay()
                
if __name__ == '__main__':
    app = QtGui.QApplication(sys.argv)
    window = Window()
    window.resize(800, 414)
    window.show()
    sys.exit(app.exec_())



