#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#

import os
import shutil
import configparser
import wnfwecker_const as C
import socket
import time
import bg_helper as bh
import netifaces

import logging
from logging.handlers import RotatingFileHandler

logFormatter = logging.Formatter('%(asctime)s %(levelname)s) %(message)s')
logFileName = 'wnfwecker.log'

logHandler = RotatingFileHandler(logFileName, mode='a', maxBytes=5 * 1024 * 1024,
                                 backupCount=2, encoding=None, delay=0)
logHandler.setFormatter(logFormatter)
#logHandler.setLevel(logging.INFO)
logHandler.setLevel(logging.DEBUG)

print(logHandler.baseFilename)

logFile = logging.getLogger('root')
#logFile.setLevel(logging.INFO)
logFile.setLevel(logging.DEBUG)
logFile.addHandler(logHandler)


def _info(s):
    print(s)
    logFile.info(s)


def _debug(s):
    # print(s)
    logFile.debug(s)


#http://stackoverflow.com/questions/35817/how-to-escape-os-system-calls-in-python
def shellquote(s):
    return "'" + s.replace("'", "'\\''") + "'"


def wnfFileExists(aDateiname):
    b=os.path.exists(aDateiname)
    if (b):
       b=os.path.isfile(aDateiname)
    return b
    
def wnfFileExistsAndNZ(aDateiname):
    b=wnfFileExists(aDateiname)
    if (b):
       a=os.stat(aDateiname)
       b=(a.st_size>0) 
    return b

def wnfFileDelete(aDateiname):
    os.remove(aDateiname)

def wnfForceDirectories(aDir):
    if not os.path.exists(aDir):
        os.makedirs(aDir)

def wnfClearDirectory(aDir):
    for the_file in os.listdir(aDir):
        file_path = os.path.join(aDir, the_file)
        try:
            if os.path.isfile(file_path):
                os.unlink(file_path)
            elif os.path.isdir(file_path):
                shutil.rmtree(file_path)
        except Exception as e:
            print(e)

def wnfCurrentDirectory():
    return os.path.abspath(os.getcwd())

def isint(s):
    try:
        i=int(s)
    except:
        return False
    else:
        return True
        
def strToIntDef(s,aDefault=0):
    try:
        i=int(s)
    except:
        return aDefault
    else:
        return i

def getHHMMSS():
    return time.strftime("%H:%M:%S")

def getHostname():
    return socket.gethostname()

def getDefaultGateWay():
    gateways = netifaces.gateways()
    return gateways['default'][netifaces.AF_INET][0]

def rebootErlaubt():
    aHostname = getHostname()
    if aHostname=='radio':
        return True
    if aHostname=='wecker':
        return True
    return False

def kommando(aKommando):
    output = bh.run_output(aKommando, timeout=2)
    _info(output)

def _error(s):
    print('ERROR: %s' % s)

def iniGetString(aSection, aKey):
    try:
        ini = configparser.ConfigParser()
        dn = os.path.join(os.path.dirname(__file__), C.INIDATEINAME)
        ini.read(dn)
        config = ini[aSection]
        if config:
            s = config.get(aKey)
            if s:
                return s
            else:
                return ''
        else:
            return ''
    except Exception as E:
        # _error(E.args)
        _error('In der Inidatei %s ist kein Wert in Section [%s] für Schlüssel %s festgelegt.' % (
        C.INIDATEINAME, aSection, aKey))
        _error(dn)

        return ''

def iniGetSectionWeckzeiten(aKey):
    return iniGetString('Weckzeiten', aKey)

def iniGetSectionBottle(aKey):
    return iniGetString('Bottle', aKey)

def iniGetBottlePort():
    return int(iniGetSectionBottle('Port'))


def main():
    aDateiname = '/tmp/einslive.m3u'
    if not wnfFileExistsAndNZ(aDateiname):
        print("Keine Verbindung zum Internet")
        return False
    return 0

if __name__ == '__main__':
    main()
        
