#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#

# Literatur
# http://codeboje.de/playing-mp3-stream-python/

#import os
import time
import datetime
import subprocess
import wnfwecker_ini
import wnfwecker_date

ini = wnfwecker_ini.iniObject()

cWeckdauerInMinuten = "30"

fNaechsteWeckZeit = None;


def mkHeute(mmhh):
    x = time.strptime(mmhh, "%H:%M")
    dt = datetime.datetime.today()
    dt = dt.replace(hour=x.tm_hour, minute=x.tm_min, second=0, microsecond=0)
    # print('mkHeute',dt)
    return dt


def mkDatum(aDatum, mmhh):
    dt = datetime.datetime.today()
    y = time.strptime(aDatum, "%d.%m.%Y")
    dt = dt.replace(year=y.tm_year, month=y.tm_mon, day=y.tm_mday)
    x = time.strptime(mmhh, "%H:%M")
    dt = dt.replace(hour=x.tm_hour, minute=x.tm_min, second=0, microsecond=0)
    # print dt
    return dt


def isEingeschaltet(logFile):
    ini.refreshWennNoetig(logFile)
    return ini.isEingeschaltet()


def isWeckZeit_x(dt, aWeckzeit, aWeckdauerInMinuten):
    if (aWeckzeit == ''):
        return False
    # print('isWeckZeit_x',aWeckzeit)
    # Die Weckzeit hat eine Dauer von einer Stunde nach der Zeit t
    von = mkHeute(aWeckzeit)
    # print('isWeckZeit_x',von)
    # von = mkDatum("30.04.2015",aWeckzeit)
    # von = mkDatum("15.05.2015",aWeckzeit)
    bis = von + datetime.timedelta(minutes=int(aWeckdauerInMinuten))
    # print('isWeckZeit_x',von,dt,bis)
    b = von.time() <= dt.time() <= bis.time()
    # print('isWeckZeit_x',b,von.time(),dt.time(),bis.time())
    return b


def isWeckZeit(dt, logFile):
    try:
        ini.refreshWennNoetig(logFile)
        aWeckdauer = ini.weckDauerInMinuten()
        aBundesland = ini.bundesland()
        # aWeckzeit = '00:00'
        s = wnfwecker_date.sFeiertag(dt, aBundesland)
        u = ini.isUrlaub(dt.strftime("%d.%m.%Y"))
        # print(dt,s)
        if (s != ''):
            aWeckzeit = ini.weckZeit('Feiertag')
        elif (u):
            aWeckzeit = ini.weckZeit('Urlaub')
        elif (dt.weekday() == 0):
            aWeckzeit = ini.weckZeit('Montag')
        elif (dt.weekday() == 1):
            aWeckzeit = ini.weckZeit('Dienstag')
        elif (dt.weekday() == 2):
            aWeckzeit = ini.weckZeit('Mittwoch')
        elif (dt.weekday() == 3):
            aWeckzeit = ini.weckZeit('Donnerstag')
        elif (dt.weekday() == 4):
            aWeckzeit = ini.weckZeit('Freitag')
        elif (dt.weekday() == 5):
            aWeckzeit = ini.weckZeit('Samstag')
        elif (dt.weekday() == 6):
            aWeckzeit = ini.weckZeit('Sonntag')
        else:
            aWeckzeit = ''
        # print('isWeckZeit',dt.weekday(), aWeckzeit,aWeckdauer)
        if isWeckZeit_x(dt, aWeckzeit, aWeckdauer):
            return True
        return False
    except Exception as E:
        print('isWeckZeit', E)
        return False


def getNextWeckzeit(dt, logFile):
    global fNaechsteWeckZeit
    # print(fNaechsteWeckZeit)
    if (ini.refreshWennNoetig(logFile)):
        fNaechsteWeckZeit = None
    if (fNaechsteWeckZeit):
        if (dt < fNaechsteWeckZeit):
            return fNaechsteWeckZeit
    aMinuten = 0
    aDiff = 1
    dt = dt.replace(second=0, microsecond=0)
    while (aMinuten < 24 * 60):
        if isWeckZeit(dt, logFile):
            fNaechsteWeckZeit = dt
            #print(fNaechsteWeckZeit)
            return dt
        dt = dt + datetime.timedelta(minutes=aDiff)
        # print (dt.strftime("%d.%m.%Y %H:%M"))
        aMinuten = aMinuten + aDiff
    return None


def zeitBisZumAufstehen(dt, logFile):
    nt = getNextWeckzeit(dt, logFile)
    if nt == None:
        return 'In den nächsten 24 Studen wird nicht geweckt.'
    else:
        delta = nt - dt
        # print(delta)
        h = ':'.join(str(delta).split(':')[:1])
        m = ':'.join(str(delta).split(':')[1:2])
        return "Nächstes Klingeln in %s Stunden und %s Minuten" % (h, m)


def getTestZeitDelta(aWeckzeit):
    dt1 = datetime.datetime.today()
    dt2 = mkHeute(aWeckzeit)
    return dt2 - dt1 - datetime.timedelta(seconds=5)


def testWeckzeit(dt):
    if isWeckZeit(dt, None):
        print("wecken      ", dt.strftime("%d.%m.%Y %H:%M"))
    else:
        print("nicht wecken", dt.strftime("%d.%m.%Y %H:%M"))


def main():
    testWeckzeit(mkHeute("04:50"));
    testWeckzeit(mkHeute("05:19"));
    testWeckzeit(mkHeute("05:20"));
    testWeckzeit(mkHeute("06:59"));
    testWeckzeit(mkHeute("07:00"));
    testWeckzeit(mkHeute("07:29"));
    testWeckzeit(mkHeute("07:30"));
    testWeckzeit(mkHeute("08:30"));
    testWeckzeit(mkHeute("10:00"));
    testWeckzeit(mkHeute("10:31"));
    testWeckzeit(mkDatum("13.05.2015", "05:21"));
    testWeckzeit(mkDatum("15.05.2015", "08:20"));
    testWeckzeit(datetime.datetime.today());
    testWeckzeit(mkDatum("22.05.2018", "05:21"));
    print(getNextWeckzeit(datetime.datetime.today(), None))
    return 0


if __name__ == '__main__':
    main()
